Change log
==========

`Next version`_
~~~~~~~~~~~~~~~

`0.2`_ (2019-06-12)
~~~~~~~~~~~~~~~~~~~

- Changed the Google Analytics snippet to always anonymize IPs by
  default.
- Dropped compatibility with Python 2.
- Added Django 2.1, 2.2 and Django 3.0 to the matrix.
- Reformatted the code using black.


`0.1`_ (2017-08-29)
~~~~~~~~~~~~~~~~~~~

- Initial public version.

.. _0.1: https://github.com/matthiask/django-privacy-killer/commit/89bb93c5cdba
.. _0.2: https://github.com/matthiask/django-privacy-killer/compare/0.1...0.2
.. _Next version: https://github.com/matthiask/django-privacy-killer/compare/0.2...master
